==> zio-aws-workdocs_3-5.17.161.1-sources.jar: zio/aws/workdocs/model/ActivateUserResponse.scala <==
package zio.aws.workdocs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ActivateUserResponse(
    user: Option[zio.aws.workdocs.model.User] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workdocs.model.ActivateUserResponse = {
    import ActivateUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
      .builder()
      .optionallyWith(user.map(value => value.buildAwsValue()))(_.user)
      .build()
  }
  def asReadOnly: zio.aws.workdocs.model.ActivateUserResponse.ReadOnly =
    zio.aws.workdocs.model.ActivateUserResponse.wrap(buildAwsValue())
}
object ActivateUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workdocs.model.ActivateUserResponse =
      zio.aws.workdocs.model
        .ActivateUserResponse(user.map(value => value.asEditable))
    def user: Option[zio.aws.workdocs.model.User.ReadOnly]
    def getUser: ZIO[Any, AwsError, zio.aws.workdocs.model.User.ReadOnly] =
      AwsError.unwrapOptionField("user", user)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
  ) extends zio.aws.workdocs.model.ActivateUserResponse.ReadOnly {
    override val user: Option[zio.aws.workdocs.model.User.ReadOnly] = scala
      .Option(impl.user())
      .map(value => zio.aws.workdocs.model.User.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
  ): zio.aws.workdocs.model.ActivateUserResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-workdocs_3-7.21.15.8-sources.jar: zio/aws/workdocs/model/ActivateUserResponse.scala <==
package zio.aws.workdocs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ActivateUserResponse(
    user: Optional[zio.aws.workdocs.model.User] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workdocs.model.ActivateUserResponse = {
    import ActivateUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
      .builder()
      .optionallyWith(user.map(value => value.buildAwsValue()))(_.user)
      .build()
  }
  def asReadOnly: zio.aws.workdocs.model.ActivateUserResponse.ReadOnly =
    zio.aws.workdocs.model.ActivateUserResponse.wrap(buildAwsValue())
}
object ActivateUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workdocs.model.ActivateUserResponse =
      zio.aws.workdocs.model
        .ActivateUserResponse(user.map(value => value.asEditable))
    def user: Optional[zio.aws.workdocs.model.User.ReadOnly]
    def getUser: ZIO[Any, AwsError, zio.aws.workdocs.model.User.ReadOnly] =
      AwsError.unwrapOptionField("user", user)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
  ) extends zio.aws.workdocs.model.ActivateUserResponse.ReadOnly {
    override val user: Optional[zio.aws.workdocs.model.User.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.user())
        .map(value => zio.aws.workdocs.model.User.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workdocs.model.ActivateUserResponse
  ): zio.aws.workdocs.model.ActivateUserResponse.ReadOnly = new Wrapper(impl)
}
